

#ifndef _BLE_PEDO_AND_CAMERA_H__
#define _BLE_PEDO_AND_CAMERA_H__

#include <stdint.h>
#include <stdbool.h>
#include "ble.h"
#include "ble_srv_common.h"

#define BLE_UUID_PAC_SERVICE 0x0001
#define BLE_UUID_UART_TX_CHARACTERISTIC 0x002
#define BLE_UUID_UART_RX_CHARACTERISTIC 0x003
#define BLE_UUID_PAC_RX_CHARACTERISTIC 0x004


#define PAC_MAX_DATA_LENGTH 20



typedef struct ble_pac_s ble_pac_t;

typedef void (*ble_pac_data_handler_t) (void *p_context, ble_pac_t * p_pac, uint8_t * data, uint16_t length);

typedef struct
{
    ble_pac_data_handler_t data_handler;              /**< Event handler to be called for handling received data. */
    void *p_context;
} ble_pac_init_t;

typedef struct ble_pac_s
{
    ble_pac_data_handler_t   data_handler;            /**< Event handler to be called for handling received data. */
    void                     *DataHandlerContext;    
    uint16_t                 service_handle;          /**< Handle of Nordic UART Service (as provided by the BLE stack). */
    uint16_t                 conn_handle;             /**< Handle of the current connection (as provided by the BLE stack, is BLE_CONN_HANDLE_INVALID if not in a connection). */    
    ble_gatts_char_handles_t UartTx_handles;              /**< Handles related to the TX characteristic. */
    ble_gatts_char_handles_t UartRx_handles;              /**< Handles related to the TX characteristic. */
    
    uint8_t                  uuid_type;               /**< UUID type for Nordic UART Service Base UUID. */    
    bool                     is_uartrx_notification_enabled; 
#if !defined(_DISABLE_CAMERA_SERVICE)     
    ble_gatts_char_handles_t PacRx_handles;              /**< Handles related to the TX characteristic. */
    bool                     is_pacrx_notification_enabled;
#endif    
} ble_pac_t;


uint32_t ble_pac_init(ble_pac_t * p_pac, const ble_pac_init_t * p_pac_init);


void ble_pac_on_ble_evt(ble_pac_t * p_pac, ble_evt_t * p_ble_evt);

uint32_t ble_pac_uart_send_string(ble_pac_t * p_pac, uint8_t * string, uint16_t length);

uint32_t ble_pac_send_string(ble_pac_t * p_pac, uint8_t * string, uint16_t length);

#endif // BLE_NUS_H__

/** @} */

